@@ -1,8 +1,7 @@
-from .eltdevice import EltDevice , load_device_config, open_elt_device
+from .eltdevice import EltDevice , open_elt_device
 from .eltnode import EltNode
 from .eltrpc import EltRpc
 from .eltinterface import EltInterface
 from .eltmanager import EltManager, open_elt_manager
 from .config import GROUP, eltconfig 
-from .tools import default_node_map, default_interface_map
 from . import io
