@@ -1,5 +1,5 @@
 from . import io
-from .tools import map2interface_map, enum_group, enum_txt, EnumTool
+from .tools import  enum_group, enum_txt, get_txt
 from enum import Enum
 from .config import eltconfig, GROUP
 
@@ -17,22 +17,6 @@ from typing import Optional, Type
 import logging
 
 
-def convert_eso_device_config(confdic : dict) -> dict:
-    """ Convert a eso config file (v2) to a pydevmgr Device Config file """
-    dtype = confdic['type']
-    mapfile = confdic.get('mapfile', None)
-    if mapfile is None:
-        pass
-    else:
-        map_d = io.load_map(mapfile)
-        try:
-            map = map_d[dtype]
-        except KeyError:
-            raise ValueError("The associated map file does not contain type %r"%dtype)
-    interface_map =  map2interface_map(map, Node=EltNode.Config, Rpc=EltRpc.Config, Interface=EltInterface.Config)
-    confdic.update(interface_map)
-    return confdic               
-
 
 class CtrlConfig(BaseModel):
     # nothing by default to declare here 
@@ -74,7 +58,7 @@ class EltDeviceConfig(UaDevice.Config):
 
     @root_validator(pre=True)
     def _convert_map_file(cls, values):
-        """ when a map file is set it is load to replace the defaults suffix of the associated node """
+        """ when a map file is set it is loaded to replace the defaults suffix of the associated node """
         
         # -------------------------------------------------- 
         # Warning This is realy important to delete the mapfile from the dictionary 
@@ -129,60 +113,10 @@ class EltDeviceConfig(UaDevice.Config):
 
 
 def open_elt_device(cfgfile, key=None, path=0, prefix=""):
+    """ open a device """
     return open_device(cfgfile, key=key, path=path, prefix=prefix) 
 
-def load_device_config(
-      file_name : str, 
-      type: str = None, 
-      name: str = None, 
-      Config: Optional[Type[EltDeviceConfig]] = None
-    ) ->  EltDeviceConfig:
-    """ load a device configuration 
-    
-    Args:
-        file_name (str): relative path to a configuration file 
-                  The path is relative to one of the directory defined in the
-                  $CFGPATH environment variable
-        type (str, optional): Type of the device, if not given look into the loaded file
-        name (str, None): The device name in the config file. 
-                        If None the first device in the loaded configuration file is taken 
-    """
-    
-    allconfig = io.load_config(file_name)
-    
-    if name is None:
-        # get the first key 
-        name = next(iter(allconfig))
-        config = allconfig[name]
-    else:
-        try:
-            config = allconfig[name]
-        except KeyError:
-            raise ValueError(f"Device {name!r} does not exists on device definition file {file_name!r}")    
-    
-    config = convert_eso_device_config(config)
-            
-    if Config is None:    
-        if type is None:
-            try:
-                type = config['type']
-            except KeyError:
-                raise ValueError('type is missing')
-        try:
-            Dev = get_device_class(type)            
-        except (KeyError, ValueError):
-            logging.warning(f'type {type!r} is unknown landing to a standard, empty device')                
-            Dev = EltDevice
-        Config = Dev.Config
-    
-    return Config(**config)    
 
-
-
-
-
-    
-    
 class RpcInterface(EltInterface):
     pass      
 
@@ -316,11 +250,11 @@ class EltDevice(UaDevice):
     
     def get_error_txt(self, errcode: int) -> str:
         """ Get a text description of the given error code number """
-        return self.ERROR(errcode).txt
+        return get_txt(self.ERROR(errcode))
     
     def get_rpc_error_txt(self, rpc_errcode: int) -> str:
         """ Get a text description of the given rpc error code number """
-        return self.RpcInterface.RPC_ERROR(rpc_errcode).txt
+        return get_txt( self.RpcInterface.RPC_ERROR(rpc_errcode) )
    
 
     def get_configuration(self, exclude_unset=True, **kwargs):
